@@ -46,6 +46,24 @@ bool CInFileStream::Open(LPCWSTR fileName)
 #endif
 #endif
 
+bool CInFileStream::OpenShared(LPCTSTR fileName, bool shareForWrite)
+{
+#ifdef ENV_UNIX
+  return File.Open(fileName,_ignoreSymbolicLink);
+#else
+  return File.OpenShared(fileName, shareForWrite);
+#endif
+}
+
+#ifdef USE_WIN_FILE
+#ifndef _UNICODE
+bool CInFileStream::OpenShared(LPCWSTR fileName, bool shareForWrite)
+{
+  return File.OpenShared(fileName, shareForWrite);
+}
+#endif
+#endif
+
 STDMETHODIMP CInFileStream::Read(void *data, UInt32 size, UInt32 *processedSize)
 {
   #ifdef USE_WIN_FILE
@@ -75,7 +93,7 @@ STDMETHODIMP CStdInFileStream::Read(void *data, UInt32 size, UInt32 *processedSi
 {
   #ifdef _WIN32
   UInt32 realProcessedSize;
-  BOOL res = ::ReadFile(GetStdHandle(STD_INPUT_HANDLE), 
+  BOOL res = ::ReadFile(GetStdHandle(STD_INPUT_HANDLE),
       data, size, (DWORD *)&realProcessedSize, NULL);
   if(processedSize != NULL)
     *processedSize = realProcessedSize;
@@ -88,10 +106,10 @@ STDMETHODIMP CStdInFileStream::Read(void *data, UInt32 size, UInt32 *processedSi
   if(processedSize != NULL)
     *processedSize = 0;
   ssize_t res;
-  do 
+  do
   {
     res = read(0, data, (size_t)size);
-  } 
+  }
   while (res < 0 && (errno == EINTR));
   if (res == -1)
     return E_FAIL;
@@ -104,7 +122,7 @@ STDMETHODIMP CStdInFileStream::Read(void *data, UInt32 size, UInt32 *processedSi
   
 #endif
 
-STDMETHODIMP CInFileStream::Seek(Int64 offset, UInt32 seekOrigin, 
+STDMETHODIMP CInFileStream::Seek(Int64 offset, UInt32 seekOrigin,
     UInt64 *newPosition)
 {
   if(seekOrigin >= 3)
@@ -222,10 +240,10 @@ STDMETHODIMP CStdOutFileStream::Write(const void *data, UInt32 size, UInt32 *pro
   {
     // Seems that Windows doesn't like big amounts writing to stdout.
     // So we limit portions by 32KB.
-    UInt32 sizeTemp = (1 << 15); 
+    UInt32 sizeTemp = (1 << 15);
     if (sizeTemp > size)
       sizeTemp = size;
-    res = ::WriteFile(GetStdHandle(STD_OUTPUT_HANDLE), 
+    res = ::WriteFile(GetStdHandle(STD_OUTPUT_HANDLE),
         data, sizeTemp, (DWORD *)&realProcessedSize, NULL);
     size -= realProcessedSize;
     data = (const void *)((const Byte *)data + realProcessedSize);
@@ -237,10 +255,10 @@ STDMETHODIMP CStdOutFileStream::Write(const void *data, UInt32 size, UInt32 *pro
   #else
   
   ssize_t res;
-  do 
+  do
   {
     res = write(1, data, (size_t)size);
-  } 
+  }
   while (res < 0 && (errno == EINTR));
   if (res == -1)
     return E_FAIL;
